All Classes and Interfaces
Class
Description
JNA bindings for the AMD Display Library (ADL) on Windows.
ADL malloc callback: allocates memory and returns a pointer.
Optional runtime binding to the AMD Display Library (ADL) on Windows.
The AIX File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.AIXHardwareAbstractionLayer class.
AIX hard disk implementation.
Internet Protocol Stats implementation
C library.
64-bit timestruc required for psinfo structure
AIXNetworks class.
AIX (Advanced Interactive eXecutive) is a series of proprietary Unix operating systems developed and sold by IBM for
several of its computer platforms.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
AIX Usb Device
JNA-based utility to read the auxiliary vector from
/proc/self/auxv.BsdNetworkIF applicable to FreeBSD and OpenBSD.
Provides access to sysctl calls on FreeBSD
Wrapper classes for JNA clases which extend
ByReference intended for use in
try-with-resources blocks.CF String retrieving
C library with code common to all *nix-based operating systems.
The Core Graphics framework is based on the Quartz advanced drawing engine.
A point with X and Y coordinates
A rectangle with origin and size
A size with width and height
CUPS (Common Unix Printing System) library.
CUPS destination (printer) structure.
Utility to query device interfaces via Config Manager Device Tree functions
Utility class parsing partition information from disklabel command
Minimal JNA binding to
dxgi.dll for enumerating display adapters and reading
DXGI_ADAPTER_DESC.DedicatedVideoMemory.Maps to the Windows
DXGI_ADAPTER_DESC structure.Utility methods for DXGI adapter enumeration and matching on Windows.
Utility to query Desktop windows
JNA-specific extensions to
FileUtil for reading native types from buffers and freeing native memory.The FreeBSD File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.FreeBsdHardwareAbstractionLayer class.
FreeBSD hard disk implementation.
Internet Protocol Stats implementation
C library.
CPU Ticks
Connection info
Return type for BSD sysctl kern.boottime
FreeBSD is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD),
which was based on Research Unix.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
FreeBsd Usb Device
Utility to query fsstat
Reads from fstat.
Utility to query geom part list
Utility to query geom part list
Utility to query GPU Engine and GPU Adapter Memory performance counters.
Utility to read HKEY_PERFORMANCE_DATA information.
Utility to read session data from HKEY_USERS
The I/O Kit framework implements non-kernel access to I/O Kit objects (drivers and nubs) through the device-interface
mechanism.
Holds the return value of SMC query.
Holds the return value of SMC KeyInfo query.
Holds the return value of SMC pLimit query.
Holds the return value of SMC version query.
Holds an SMC value
IOReport is a private Apple framework that provides access to hardware performance counters, including GPU residency
and energy metrics on Apple Silicon.
Manages a single IOReport subscription for GPU Stats and Energy Model channels, providing per-instance sampling of
GPU active ticks, utilization, and power draw.
Utility to query iostat
Kernel32.
Provides access to kstat information on Solaris
A copy of the Kstat chain, encapsulating a
kstat_ctl_t object.Utility to query LibreHardwareMonitor WMI sensor data using JNA.
JNA-based Linux file system implementation.
JNA-based Linux hardware abstraction layer.
JNA-based Linux hard disk implementation.
Linux C Library.
Part of utmpx structure
Return type for getutxent()
32-bit timeval required for utmpx structure
JNA-based Linux network interface implementation.
JNA-based Linux operating system implementation.
JNA-based Linux OS process.
JNA-based Linux power source implementation.
Linux USB device helper using JNA/udev.
JNA implementation of
LoadAverage using JNA-based perfmon drivers.Utility to query Logical Processor Information
Utility to query ls
Utility to query lscfg
Utility to query lshal
Utility to query lspv
Utility to query lssrad
The Mac File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.MacHardwareAbstractionLayer JNA implementation.
Mac hard disk implementation.
Internet Protocol Stats implementation
MacNetworks JNA implementation.
macOS, previously Mac OS X and later OS X) is a series of proprietary graphical operating systems developed and
marketed by Apple Inc. since 2001.
OSFileStore implementation
OSProcess implementation
A Power Source
Mac USB device helper using JNA/IOKit.
Utility to query Memory performance counter
Utility to query mount
Utility to query WMI class
MSAcpi_ThermalZoneTemperature using JNA.Utility to query WMI classes in Storage namespace associated with Storage Pools using JNA.
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Utility to query NetStat.
Class to encapsulate IF data for method return
JNA bindings for the NVIDIA Management Library (NVML).
Optional runtime binding to the NVIDIA Management Library (NVML).
Utility to query Open Hardware Monitor WMI data for Hardware using JNA.
Utility to query Open Hardware Monitor WMI data for Sensors using JNA.
OpenBSD Central Processor implementation
OpenBSD ComputerSystem implementation
The FreeBSD File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.OpenBSD Firmware implementation
OpenBsdHardwareAbstractionLayer class.
OpenBSD hard disk implementation.
Internet Protocol Stats implementation
C library.
OpenBSD Cache stats for memory
Return type for BSD sysctl kern.boottime
OpenBsdNetworkParams class.
OpenBsd is a free and open-source Unix-like operating system descended from the Berkeley Software Distribution (BSD),
which was based on Research Unix.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
Provides access to sysctl calls on OpenBSD
OpenBsd Usb Device
Utility to query Paging File performance counter
Enables queries of Performance Counters using wild cards to filter instances
Utility to handle Performance Counter Queries
Enables queries of Performance Counters using wild cards to filter instances
Helper class to centralize the boilerplate portions of PDH counter setup and allow applications to easily add, query,
and remove counters.
Tests whether performance counters are disabled
Utility to query partition config
Utility to query performance stats for cpu
Utility to query performance stats for disk_stats
Utility to query performance stats for memory
Utility to query performance stats for network interfaces
Utility to query performance stats for processes
Utility to query performance stats for network interfaces
Utility to query PhysicalDisk performance counter
Deprecated.
Power profile stats.
Contains information about a processor.
Contains information about the current state of the system battery.
Utility to query Process Information performance counter
Utility to query Processor performance counter
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Reads from procstat into a map
Utility to query iostat
Utility to query /proc/psinfo
Utility to query /proc/psinfo
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Provides access to SMC calls on macOS
The Solaris File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.SolarisHardwareAbstractionLayer class.
Solaris hard disk implementation.
Internet Protocol Stats implementation
C library.
Part of utmpx structure
Nested Structure for psinfo file
Structure for usage file
Structure for psinfo file
Connection info
32/64-bit timestruc required for psinfo and lwpsinfo structures
32/64-bit timeval required for utmpx structure
SolarisNetworks class.
Solaris is a non-free Unix operating system originally developed by Sun Microsystems.
OSFileStore implementation
OSProcess implementation
OSThread implementation
A Power Source
Solaris Usb Device
Wrapper classes for JNA clases which extend
Structure intended for use in try-with-resources
blocks.Provides access to sysctl calls on macOS
System class.
Mac internet socket info
Mac connection info
Union for TCP or internet socket info
Mac file descriptor info
Mac file info
Mac socket info
Mack IP Socket Info
Mac TCP socket info
Allow applications to access a device’s network configuration settings.
JNA bindings for libsystemd.
System information.
Utility to query System performance counters
Utility to query geom part list
Utility to query Thread Information performance counter
Utility to read thread data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
Baseboard data obtained by a calling class
CUPS-based printer implementation for Unix-like systems.
Utility to query up time.
Utility to query logged in users.
Utility to query logged in users.
Utility to query logged in users.
Utility to query logged in users.
Utility to query logged in users.
Utility to query WMI class
Win32_BaseBoard using JNA.Utility to query WMI class
Win32_BIOS using JNA.Utility to query WMI class
Win32_ComputerSystem using JNA.Utility to query WMI class
Win32_ComputerSystemProduct using JNA.Utility to query WMI class
Win32_DiskDrive using JNA.Utility to query WMI class
Win32_DiskDriveToDiskPartition using JNA.Utility to query WMI class
Win32_DiskPartition using JNA.Utility to query WMI class
Win32_Fan using JNA.Utility to query WMI class
Win32_LogicalDisk using JNA.Utility to query WMI class
Win32_LogicalDiskToPartition using JNA.Utility to query WMI class
Win32_OperatingSystem using JNA.Utility to query WMI class
Win32_PhysicalMemory using JNA.Utility to query WMI class
Win32_Printer using JNA.Utility to query WMI class
Win32_Process using cache (JNA).Utility to query WMI class
Win32_Process using JNA.Utility to query WMI class
Win32_Processor using JNA.Utility to query WMI class
Win32_VideoController using JNA.Utility to query desktop windows
The Windows File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.WindowsHardwareAbstractionLayer class.
Windows hard disk implementation using JNA.
Internet Protocol Stats implementation
WindowsNetworks class.
Microsoft Windows, commonly referred to as Windows, is a group of several proprietary graphical operating system
families, all of which are developed and marketed by Microsoft.
JNA-based Windows OSFileStore implementation.
JNA-based Windows OS process implementation.
JNA-based Windows OS thread implementation.
JNA-based Windows power source implementation.
Windows Usb Device
Utility to handle WMI Queries.
Helper class for WMI
PlatformEnuminstead.