Enum PlatformEnum

All Implemented Interfaces:
Serializable, Comparable<PlatformEnum>

@Deprecated public enum PlatformEnum extends Enum<PlatformEnum>
Deprecated.
Use PlatformEnum instead.
An enumeration of supported operating systems. The order of declaration matches the osType constants in the JNA Platform class.
  • Enum Constant Details

  • Method Details

    • values

      public static PlatformEnum[] values()
      Deprecated.
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static PlatformEnum valueOf(String name)
      Deprecated.
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getName

      @Deprecated public String getName()
      Deprecated.
      Use PlatformEnum.getName()
      Gets the friendly name of the platform
      Returns:
      the friendly name of the platform
    • getName

      @Deprecated public static String getName(int osType)
      Deprecated.
      Use PlatformEnum.getName(int)
      Gets the friendly name of the platform corresponding to the specified JNA osType ordinal.
      Parameters:
      osType - The ordinal value matching the order of constants in this enum, corresponding to JNA's Platform.getOSType() return values.
      Returns:
      the friendly name of the specified platform type
    • getValue

      @Deprecated public static PlatformEnum getValue(int osType)
      Deprecated.
      Use PlatformEnum.getValue(int)
      Gets the value corresponding to the specified JNA osType ordinal.
      Parameters:
      osType - The ordinal value matching the order of constants in this enum, corresponding to JNA's Platform.getOSType() return values.
      Returns:
      the value corresponding to the specified platform type
    • getCurrentPlatform

      @Deprecated public static PlatformEnum getCurrentPlatform()
      Deprecated.
      Use PlatformEnum.getCurrentPlatform()
      Gets the current platform, detected from system properties without loading JNA.
      Returns:
      the current platform