Uses of Enum
oshi.PlatformEnum
Packages that use PlatformEnum
Package
Description
[oshi-core API] Provides a cross-platform implementation to retrieve Operating System and Hardware Information, such
as OS version, memory, CPU, disk, devices, sensors, etc.
-
Uses of PlatformEnum in oshi
Subclasses with type arguments of type PlatformEnum in oshiMethods in oshi that return PlatformEnumModifier and TypeMethodDescriptionstatic PlatformEnumPlatformEnum.getCurrentPlatform()Deprecated.UsePlatformEnum.getCurrentPlatform()static PlatformEnumSystemInfo.getCurrentPlatform()Deprecated.UsePlatformEnum.getCurrentPlatform()instead.static PlatformEnumPlatformEnum.getValue(int osType) Deprecated.UsePlatformEnum.getValue(int)static PlatformEnumDeprecated.Returns the enum constant of this type with the specified name.static PlatformEnum[]PlatformEnum.values()Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.
PlatformEnuminstead.