Package oshi.driver.linux.proc


package oshi.driver.linux.proc
Provides functions to query statistics in the Linux /proc pseudo-filesystem
  • Classes
    Class
    Description
    JNA-based utility to read the auxiliary vector from /proc/self/auxv.