Class ThreadInformationJNA
java.lang.Object
oshi.driver.windows.perfmon.ThreadInformationJNA
Utility to query Thread Information performance counter
-
Method Summary
Modifier and TypeMethodDescriptionstatic oshi.util.tuples.Pair<List<String>, Map<oshi.driver.common.windows.perfmon.ThreadInformation.ThreadPerformanceProperty, List<Long>>> Returns thread counters.static oshi.util.tuples.Pair<List<String>, Map<oshi.driver.common.windows.perfmon.ThreadInformation.ThreadPerformanceProperty, List<Long>>> queryThreadCounters(String name, int threadNum) Returns thread counters filtered to the specified process name and thread.
-
Method Details
-
queryThreadCounters
-
queryThreadCounters
public static oshi.util.tuples.Pair<List<String>, Map<oshi.driver.common.windows.perfmon.ThreadInformation.ThreadPerformanceProperty, List<Long>>> queryThreadCounters(String name, int threadNum) Returns thread counters filtered to the specified process name and thread.- Parameters:
name- The process name to filterthreadNum- The thread number to match. -1 matches all threads.- Returns:
- Thread counters for each thread.
-