Class HWPartition
java.lang.Object
oshi.hardware.HWPartition
A region on a hard disk or other secondary storage, so that an operating system can manage information in each region
separately. A partition appears in the operating system as a distinct "logical" disk that uses part of the actual
disk.
-
Constructor Summary
ConstructorsConstructorDescriptionHWPartition(String identification, String name, String type, String uuid, long size, int major, int minor, String mountPoint) Creates a new HWPartitionHWPartition(String identification, String name, String type, String uuid, String label, long size, int major, int minor, String mountPoint) Creates a new HWPartition -
Method Summary
Modifier and TypeMethodDescriptionGetter for the fieldidentification.getLabel()Getter for the fieldlabel.intgetMajor()Getter for the fieldmajor.intgetMinor()Getter for the fieldminor.Getter for the fieldmountPoint.getName()Getter for the fieldname.longgetSize()Getter for the fieldsize.getType()Getter for the fieldtype.getUuid()Getter for the fielduuid.toString()
-
Constructor Details
-
HWPartition
public HWPartition(String identification, String name, String type, String uuid, long size, int major, int minor, String mountPoint) Creates a new HWPartition- Parameters:
identification- The unique partition idname- Friendly name of the partitiontype- Type or description of the partitionuuid- UUIDsize- Size in bytesmajor- Device ID (Major)minor- Device ID (Minor)mountPoint- Where the partition is mounted
-
HWPartition
public HWPartition(String identification, String name, String type, String uuid, String label, long size, int major, int minor, String mountPoint) Creates a new HWPartition- Parameters:
identification- The unique partition idname- Friendly name of the partitiontype- Type or description of the partitionuuid- UUIDlabel- Partition labelsize- Size in bytesmajor- Device ID (Major)minor- Device ID (Minor)mountPoint- Where the partition is mounted
-
-
Method Details
-
getIdentification
Getter for the field
identification.- Returns:
- Returns the identification.
-
getName
-
getType
-
getUuid
-
getLabel
-
getSize
public long getSize()Getter for the field
size.- Returns:
- Returns the size in bytes.
-
getMajor
public int getMajor()Getter for the field
major.- Returns:
- Returns the major device ID.
-
getMinor
public int getMinor()Getter for the field
minor.- Returns:
- Returns the minor device ID.
-
getMountPoint
-
toString
-