Uses of Enum
oshi.hardware.Printer.PrinterStatus
Packages that use Printer.PrinterStatus
Package
Description
[oshi-core API] Provides cross-platform implementation to retrieve hardware information such as CPU, Memory, Display,
Disks, Network Interfaces, Power Sources, Sensors, and USB Devices
Provides abstract classes for common code
-
Uses of Printer.PrinterStatus in oshi.hardware
Subclasses with type arguments of type Printer.PrinterStatus in oshi.hardwareMethods in oshi.hardware that return Printer.PrinterStatusModifier and TypeMethodDescriptionPrinter.getStatus()Retrieves the current status of the printer.static Printer.PrinterStatusReturns the enum constant of this type with the specified name.static Printer.PrinterStatus[]Printer.PrinterStatus.values()Returns an array containing the constants of this enum type, in the order they are declared. -
Uses of Printer.PrinterStatus in oshi.hardware.common
Methods in oshi.hardware.common that return Printer.PrinterStatusConstructors in oshi.hardware.common with parameters of type Printer.PrinterStatusModifierConstructorDescriptionprotectedAbstractPrinter(String name, String driverName, String description, Printer.PrinterStatus status, String statusReason, boolean isDefault, boolean isLocal, String portName)