Class LinuxHardwareAbstractionLayer
java.lang.Object
oshi.hardware.common.AbstractHardwareAbstractionLayer
oshi.hardware.platform.linux.LinuxHardwareAbstractionLayer
- All Implemented Interfaces:
HardwareAbstractionLayer
- Direct Known Subclasses:
LinuxHardwareAbstractionLayerJNA
@ThreadSafe
public abstract class LinuxHardwareAbstractionLayer
extends AbstractHardwareAbstractionLayer
LinuxHardwareAbstractionLayer class.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionInstantiates the platform-specificComputerSystemobjectInstantiates the platform-specificGlobalMemoryobjectInstantiates the platform-specificCentralProcessorobjectInstantiates the platform-specificSensorsobjectInstantiates a list ofDisplayobjects, representing monitors or other video output devices.Instantiates a list ofGraphicsCardobjects, representing the Graphics cards.Instantiates a list ofPrinterobjects, representing printers.Instantiates a list ofSoundCardobjects, representing the Sound cards.Methods inherited from class AbstractHardwareAbstractionLayer
getComputerSystem, getMemory, getNetworkIFs, getProcessor, getSensorsMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface HardwareAbstractionLayer
getDiskStores, getLogicalVolumeGroups, getNetworkIFs, getPowerSources, getUsbDevices
-
Constructor Details
-
LinuxHardwareAbstractionLayer
public LinuxHardwareAbstractionLayer()
-
-
Method Details
-
createComputerSystem
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificComputerSystemobject- Specified by:
createComputerSystemin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
ComputerSystemobject
-
createMemory
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificGlobalMemoryobject- Specified by:
createMemoryin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
GlobalMemoryobject
-
createProcessor
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificCentralProcessorobject- Specified by:
createProcessorin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
CentralProcessorobject
-
createSensors
Description copied from class:AbstractHardwareAbstractionLayerInstantiates the platform-specificSensorsobject- Specified by:
createSensorsin classAbstractHardwareAbstractionLayer- Returns:
- platform-specific
Sensorsobject
-
getDisplays
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofDisplayobjects, representing monitors or other video output devices.- Returns:
- A list of Display objects or an empty list if none are present.
-
getSoundCards
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofSoundCardobjects, representing the Sound cards.- Returns:
- A list of SoundCard objects or an empty list if none are present.
-
getGraphicsCards
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofGraphicsCardobjects, representing the Graphics cards.- Returns:
- A list of objects or an empty list if none are present.
-
getPrinters
Description copied from interface:HardwareAbstractionLayerInstantiates a list ofPrinterobjects, representing printers.- Returns:
- A list of Printer objects or an empty list if none are present.
-