Class LinuxPowerSourceJNA
java.lang.Object
oshi.hardware.common.AbstractPowerSource
oshi.hardware.platform.linux.LinuxPowerSource
oshi.hardware.platform.linux.LinuxPowerSourceJNA
- All Implemented Interfaces:
PowerSource
JNA-based Linux power source implementation.
-
Nested Class Summary
Nested classes/interfaces inherited from class LinuxPowerSource
LinuxPowerSource.PropNested classes/interfaces inherited from interface PowerSource
PowerSource.CapacityUnits -
Method Summary
Modifier and TypeMethodDescriptionstatic List<PowerSource> Gets Battery Informationprotected List<PowerSource> Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes().Methods inherited from class LinuxPowerSource
buildPowerSourceMethods inherited from class AbstractPowerSource
getAmperage, getCapacityUnits, getChemistry, getCurrentCapacity, getCycleCount, getDesignCapacity, getDeviceName, getManufactureDate, getManufacturer, getMaxCapacity, getName, getPowerUsageRate, getRemainingCapacityPercent, getSerialNumber, getTemperature, getTimeRemainingEstimated, getTimeRemainingInstant, getVoltage, isCharging, isDischarging, isPowerOnLine, toString, updateAttributes
-
Method Details
-
queryPowerSources
Description copied from class:AbstractPowerSourceReturns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). Each concrete subclass implements this by delegating to its own staticgetPowerSources()factory method.- Overrides:
queryPowerSourcesin classLinuxPowerSource- Returns:
- A list of PowerSource objects representing batteries, etc.
-
getPowerSources
Gets Battery Information- Returns:
- A list of PowerSource objects representing batteries, etc.
-