Class LinuxUsbDeviceJNA

java.lang.Object
oshi.hardware.common.AbstractUsbDevice
oshi.hardware.common.platform.linux.LinuxUsbDevice
oshi.hardware.platform.linux.LinuxUsbDeviceJNA
All Implemented Interfaces:
Comparable<oshi.hardware.UsbDevice>, oshi.hardware.UsbDevice

public final class LinuxUsbDeviceJNA extends oshi.hardware.common.platform.linux.LinuxUsbDevice
Linux USB device helper using JNA/udev. Instantiates LinuxUsbDevice objects.
  • Method Summary

    Modifier and Type
    Method
    Description
    static List<oshi.hardware.UsbDevice>
    getUsbDevices(boolean tree)
    Instantiates a list of UsbDevice objects, representing devices connected via a usb port (including internal devices).

    Methods inherited from class oshi.hardware.common.platform.linux.LinuxUsbDevice

    getDeviceAndChildren

    Methods inherited from class oshi.hardware.common.AbstractUsbDevice

    addDevicesToList, compareTo, getConnectedDevices, getName, getProductId, getSerialNumber, getUniqueDeviceId, getVendor, getVendorId, toString

    Methods inherited from class Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
  • Method Details

    • getUsbDevices

      public static List<oshi.hardware.UsbDevice> getUsbDevices(boolean tree)
      Instantiates a list of UsbDevice objects, representing devices connected via a usb port (including internal devices).

      If the value of tree is true, the top level devices returned from this method are the USB Controllers; connected hubs and devices in its device tree share that controller's bandwidth. If the value of tree is false, USB devices (not controllers) are listed in a single flat list.

      Parameters:
      tree - If true, returns a list of controllers, which requires recursive iteration of connected devices. If false, returns a flat list of devices excluding controllers.
      Returns:
      a list of UsbDevice objects.