Class MacPowerSource
java.lang.Object
oshi.hardware.common.AbstractPowerSource
oshi.hardware.platform.mac.MacPowerSource
- All Implemented Interfaces:
PowerSource
A Power Source
-
Nested Class Summary
Nested classes/interfaces inherited from interface PowerSource
PowerSource.CapacityUnits -
Constructor Summary
ConstructorsConstructorDescriptionMacPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) -
Method Summary
Modifier and TypeMethodDescriptionstatic List<PowerSource> Gets Battery Information.protected List<PowerSource> Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes().Methods inherited from class AbstractPowerSource
getAmperage, getCapacityUnits, getChemistry, getCurrentCapacity, getCycleCount, getDesignCapacity, getDeviceName, getManufactureDate, getManufacturer, getMaxCapacity, getName, getPowerUsageRate, getRemainingCapacityPercent, getSerialNumber, getTemperature, getTimeRemainingEstimated, getTimeRemainingInstant, getVoltage, isCharging, isDischarging, isPowerOnLine, toString, updateAttributes
-
Constructor Details
-
MacPowerSource
public MacPowerSource(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature)
-
-
Method Details
-
queryPowerSources
Description copied from class:AbstractPowerSourceReturns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). Each concrete subclass implements this by delegating to its own staticgetPowerSources()factory method.- Specified by:
queryPowerSourcesin classAbstractPowerSource- Returns:
- A list of PowerSource objects representing batteries, etc.
-
getPowerSources
Gets Battery Information.- Returns:
- An array of PowerSource objects representing batteries, etc.
-