Interface CoreGraphics
- All Superinterfaces:
Library
The Core Graphics framework is based on the Quartz advanced drawing engine. It provides low-level, lightweight 2D
rendering with unmatched output fidelity. You use this framework to handle path-based drawing, transformations, color
management, offscreen rendering, patterns, gradients and shadings, image data management, image creation, and image
masking, as well as PDF document creation, display, and parsing.
In macOS, Core Graphics also includes services for working with display hardware, low-level user input events, and the windowing system.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic classA point with X and Y coordinatesstatic classA rectangle with origin and sizestatic classA size with width and heightNested classes/interfaces inherited from interface Library
Library.Handler -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final CoreGraphicsstatic final intstatic final intstatic final intstatic final intstatic final intstatic final intstatic final int -
Method Summary
Modifier and TypeMethodDescriptionbooleanCGRectMakeWithDictionaryRepresentation(CoreFoundation.CFDictionaryRef dict, CoreGraphics.CGRect rect) CGWindowListCopyWindowInfo(int option, int relativeToWindow)
-
Field Details
-
INSTANCE
-
kCGNullWindowID
static final int kCGNullWindowID- See Also:
-
kCGWindowListOptionAll
static final int kCGWindowListOptionAll- See Also:
-
kCGWindowListOptionOnScreenOnly
static final int kCGWindowListOptionOnScreenOnly- See Also:
-
kCGWindowListOptionOnScreenAboveWindow
static final int kCGWindowListOptionOnScreenAboveWindow- See Also:
-
kCGWindowListOptionOnScreenBelowWindow
static final int kCGWindowListOptionOnScreenBelowWindow- See Also:
-
kCGWindowListOptionIncludingWindow
static final int kCGWindowListOptionIncludingWindow- See Also:
-
kCGWindowListExcludeDesktopElements
static final int kCGWindowListExcludeDesktopElements- See Also:
-
-
Method Details
-
CGWindowListCopyWindowInfo
-
CGRectMakeWithDictionaryRepresentation
boolean CGRectMakeWithDictionaryRepresentation(CoreFoundation.CFDictionaryRef dict, CoreGraphics.CGRect rect)
-