Package oshi.software.os.linux
package oshi.software.os.linux
Provides information about Software and OS on Linux
-
ClassesClassDescriptionThe Linux File System contains
OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.JNA-based Linux file system implementation.Internet Protocol Stats implementationLinux is a family of open source Unix-like operating systems based on the Linux kernel, an operating system kernel first released on September 17, 1991, by Linus Torvalds.JNA-based Linux operating system implementation.OSFileStore implementationOSProcess implementationJNA-based Linux OS process.OSThread implementation