Class MacFileSystemJNA

java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.common.os.mac.MacFileSystem
oshi.software.os.mac.MacFileSystemJNA
All Implemented Interfaces:
oshi.software.os.FileSystem

@ThreadSafe public class MacFileSystemJNA extends oshi.software.common.os.mac.MacFileSystem
The Mac File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. In macOS, these are found in the /Volumes directory.
  • Field Summary

    Fields inherited from class oshi.software.common.os.mac.MacFileSystem

    FS_PATH_EXCLUDES, FS_PATH_INCLUDES, FS_VOLUME_EXCLUDES, FS_VOLUME_INCLUDES, LOCAL_DISK, MNT_ASYNC, MNT_AUTOMOUNTED, MNT_CPROTECT, MNT_DEFWRITE, MNT_DONTBROWSE, MNT_DOVOLFS, MNT_EXPORTED, MNT_IGNORE_OWNERSHIP, MNT_JOURNALED, MNT_LOCAL, MNT_MULTILABEL, MNT_NOATIME, MNT_NODEV, MNT_NOEXEC, MNT_NOSUID, MNT_NOUSERXATTR, MNT_QUARANTINE, MNT_QUOTA, MNT_RDONLY, MNT_ROOTFS, MNT_SYNCHRONOUS, MNT_UNION, OPTIONS_MAP, OSHI_MAC_FS_PATH_EXCLUDES, OSHI_MAC_FS_PATH_INCLUDES, OSHI_MAC_FS_VOLUME_EXCLUDES, OSHI_MAC_FS_VOLUME_INCLUDES

    Fields inherited from class oshi.software.common.AbstractFileSystem

    NETWORK_FS_TYPES, PSEUDO_FS_TYPES
  • Constructor Summary

    Constructors
    Constructor
    Description
     
  • Method Summary

    Modifier and Type
    Method
    Description
    List<oshi.software.os.OSFileStore>
    getFileStores(boolean localOnly)
     
    long
     
    long
     
    long
     

    Methods inherited from class oshi.software.common.AbstractFileSystem

    getFileStores

    Methods inherited from class Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • MacFileSystemJNA

      public MacFileSystemJNA()
  • Method Details

    • getFileStores

      public List<oshi.software.os.OSFileStore> getFileStores(boolean localOnly)
    • getOpenFileDescriptors

      public long getOpenFileDescriptors()
    • getMaxFileDescriptors

      public long getMaxFileDescriptors()
    • getMaxFileDescriptorsPerProcess

      public long getMaxFileDescriptorsPerProcess()