Class AixFileSystem

java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.os.unix.aix.AixFileSystem
All Implemented Interfaces:
oshi.software.os.FileSystem

@ThreadSafe public class AixFileSystem extends oshi.software.common.AbstractFileSystem
The AIX File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage.
  • Field Details

  • Constructor Details

    • AixFileSystem

      public AixFileSystem()
  • Method Details

    • getFileStores

      public List<oshi.software.os.OSFileStore> getFileStores(boolean localOnly)
    • getOpenFileDescriptors

      public long getOpenFileDescriptors()
    • getMaxFileDescriptors

      public long getMaxFileDescriptors()
    • getMaxFileDescriptorsPerProcess

      public long getMaxFileDescriptorsPerProcess()