Class SolarisFileSystem

java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.os.unix.solaris.SolarisFileSystem
All Implemented Interfaces:
oshi.software.os.FileSystem

@ThreadSafe public class SolarisFileSystem extends oshi.software.common.AbstractFileSystem
The Solaris File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. In Solaris, these are found in the /proc/mount filesystem, excluding temporary and kernel mounts.
  • Field Details

  • Constructor Details

    • SolarisFileSystem

      public SolarisFileSystem()
  • Method Details

    • getFileStores

      public List<oshi.software.os.OSFileStore> getFileStores(boolean localOnly)
    • getOpenFileDescriptors

      public long getOpenFileDescriptors()
    • getMaxFileDescriptors

      public long getMaxFileDescriptors()
    • getMaxFileDescriptorsPerProcess

      public long getMaxFileDescriptorsPerProcess()