Class SolarisOperatingSystem
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.os.unix.solaris.SolarisOperatingSystem
- All Implemented Interfaces:
oshi.software.os.OperatingSystem
@ThreadSafe
public class SolarisOperatingSystem
extends oshi.software.common.AbstractOperatingSystem
Solaris is a non-free Unix operating system originally developed by Sun Microsystems. It superseded the company's
earlier SunOS in 1993. In 2010, after the Sun acquisition by Oracle, it was renamed Oracle Solaris.
-
Nested Class Summary
Nested classes/interfaces inherited from interface oshi.software.os.OperatingSystem
oshi.software.os.OperatingSystem.OSVersionInfo, oshi.software.os.OperatingSystem.ProcessFiltering, oshi.software.os.OperatingSystem.ProcessSorting -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final booleanThis static field identifies if the kstat2 library (available in Solaris 11.4 or greater) can be loaded.Fields inherited from class oshi.software.common.AbstractOperatingSystem
USE_WHO_COMMAND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionoshi.software.os.OSThreadoshi.software.os.FileSystemoshi.software.os.InternetProtocolStatsoshi.software.os.NetworkParamsoshi.software.os.OSProcessgetProcess(int pid) intintList<oshi.software.os.OSService> List<oshi.software.os.OSSession> longlongintintList<oshi.software.os.OSProcess> protected intqueryBitness(int jvmBitness) List<oshi.software.os.OSProcess> queryChildProcesses(int parentPid) List<oshi.software.os.OSProcess> queryDescendantProcesses(int parentPid) oshi.util.tuples.Pair<String, oshi.software.os.OperatingSystem.OSVersionInfo> Methods inherited from class oshi.software.common.AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getDesktopWindows, getFamily, getManufacturer, getProcesses, getVersionInfo, isElevated, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface oshi.software.os.OperatingSystem
getCurrentProcess, getInstalledApplications, getProcesses, getProcesses
-
Field Details
-
HAS_KSTAT2
public static final boolean HAS_KSTAT2This static field identifies if the kstat2 library (available in Solaris 11.4 or greater) can be loaded.
-
-
Constructor Details
-
SolarisOperatingSystem
public SolarisOperatingSystem()
-
-
Method Details
-
queryManufacturer
- Specified by:
queryManufacturerin classoshi.software.common.AbstractOperatingSystem
-
queryFamilyVersionInfo
public oshi.util.tuples.Pair<String, oshi.software.os.OperatingSystem.OSVersionInfo> queryFamilyVersionInfo()- Specified by:
queryFamilyVersionInfoin classoshi.software.common.AbstractOperatingSystem
-
queryBitness
protected int queryBitness(int jvmBitness) - Specified by:
queryBitnessin classoshi.software.common.AbstractOperatingSystem
-
getFileSystem
public oshi.software.os.FileSystem getFileSystem() -
getInternetProtocolStats
public oshi.software.os.InternetProtocolStats getInternetProtocolStats() -
getSessions
- Specified by:
getSessionsin interfaceoshi.software.os.OperatingSystem- Overrides:
getSessionsin classoshi.software.common.AbstractOperatingSystem
-
getProcess
public oshi.software.os.OSProcess getProcess(int pid) -
queryAllProcesses
- Specified by:
queryAllProcessesin classoshi.software.common.AbstractOperatingSystem
-
queryChildProcesses
- Specified by:
queryChildProcessesin classoshi.software.common.AbstractOperatingSystem
-
queryDescendantProcesses
- Specified by:
queryDescendantProcessesin classoshi.software.common.AbstractOperatingSystem
-
getProcessId
public int getProcessId() -
getProcessCount
public int getProcessCount() -
getThreadId
public int getThreadId() -
getCurrentThread
public oshi.software.os.OSThread getCurrentThread() -
getThreadCount
public int getThreadCount() -
getSystemUptime
public long getSystemUptime() -
getSystemBootTime
public long getSystemBootTime() -
getNetworkParams
public oshi.software.os.NetworkParams getNetworkParams() -
getServices
-