Class WindowsFileSystemJNA

java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.os.windows.WindowsFileSystemJNA
All Implemented Interfaces:
oshi.software.os.FileSystem

@ThreadSafe public class WindowsFileSystemJNA extends oshi.software.common.AbstractFileSystem
The Windows File System contains OSFileStores which are a storage pool, device, partition, volume, concrete file system or other implementation specific means of file storage. In Windows, these are represented by a drive letter, e.g., "A:\" and "C:\"
  • Constructor Details

    • WindowsFileSystemJNA

      public WindowsFileSystemJNA()
      Constructor for WindowsFileSystemJNA. Sets the Windows error mode via Kernel32.INSTANCE.SetErrorMode(SEM_FAILCRITICALERRORS) to suppress system prompts for floppy/CD-ROM drives that have no media.
  • Method Details

    • getFileStores

      public List<oshi.software.os.OSFileStore> getFileStores(boolean localOnly)
    • getOpenFileDescriptors

      public long getOpenFileDescriptors()
    • getMaxFileDescriptors

      public long getMaxFileDescriptors()
    • getMaxFileDescriptorsPerProcess

      public long getMaxFileDescriptorsPerProcess()