Class WindowsOperatingSystemJNA
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.common.os.windows.WindowsOperatingSystem
oshi.software.os.windows.WindowsOperatingSystemJNA
- All Implemented Interfaces:
oshi.software.os.OperatingSystem
@ThreadSafe
public class WindowsOperatingSystemJNA
extends oshi.software.common.os.windows.WindowsOperatingSystem
Microsoft Windows, commonly referred to as Windows, is a group of several proprietary graphical operating system
families, all of which are developed and marketed by Microsoft.
-
Nested Class Summary
Nested classes/interfaces inherited from interface oshi.software.os.OperatingSystem
oshi.software.os.OperatingSystem.OSVersionInfo, oshi.software.os.OperatingSystem.ProcessFiltering, oshi.software.os.OperatingSystem.ProcessSorting -
Field Summary
Fields inherited from class oshi.software.common.os.windows.WindowsOperatingSystem
USE_PROCSTATE_SUSPENDEDFields inherited from class oshi.software.common.AbstractOperatingSystem
USE_WHO_COMMAND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionoshi.software.os.OSThreadList<oshi.software.os.OSDesktopWindow> getDesktopWindows(boolean visibleOnly) oshi.software.os.FileSystemList<oshi.software.os.ApplicationInfo> oshi.software.os.InternetProtocolStatsoshi.software.os.NetworkParamsoshi.software.os.OSProcessgetProcess(int pid) intList<oshi.software.os.OSProcess> getProcesses(Collection<Integer> pids) intList<oshi.software.os.OSService> List<oshi.software.os.OSSession> longlongintintbooleanList<oshi.software.os.OSProcess> protected intqueryBitness(int jvmBitness) List<oshi.software.os.OSProcess> queryChildProcesses(int parentPid) List<oshi.software.os.OSProcess> queryDescendantProcesses(int parentPid) oshi.util.tuples.Pair<String, oshi.software.os.OperatingSystem.OSVersionInfo> Methods inherited from class oshi.software.common.os.windows.WindowsOperatingSystem
parseCodeName, queryManufacturerMethods inherited from class oshi.software.common.AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getFamily, getManufacturer, getProcesses, getVersionInfo, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface oshi.software.os.OperatingSystem
getCurrentProcess, getProcesses
-
Constructor Details
-
WindowsOperatingSystemJNA
public WindowsOperatingSystemJNA()
-
-
Method Details
-
queryFamilyVersionInfo
public oshi.util.tuples.Pair<String, oshi.software.os.OperatingSystem.OSVersionInfo> queryFamilyVersionInfo()- Specified by:
queryFamilyVersionInfoin classoshi.software.common.AbstractOperatingSystem
-
queryBitness
protected int queryBitness(int jvmBitness) - Specified by:
queryBitnessin classoshi.software.common.AbstractOperatingSystem
-
isElevated
public boolean isElevated()- Specified by:
isElevatedin interfaceoshi.software.os.OperatingSystem- Overrides:
isElevatedin classoshi.software.common.AbstractOperatingSystem
-
getFileSystem
public oshi.software.os.FileSystem getFileSystem() -
getInternetProtocolStats
public oshi.software.os.InternetProtocolStats getInternetProtocolStats() -
getSessions
- Specified by:
getSessionsin interfaceoshi.software.os.OperatingSystem- Overrides:
getSessionsin classoshi.software.common.AbstractOperatingSystem
-
getProcesses
-
queryAllProcesses
- Specified by:
queryAllProcessesin classoshi.software.common.AbstractOperatingSystem
-
queryChildProcesses
- Specified by:
queryChildProcessesin classoshi.software.common.AbstractOperatingSystem
-
queryDescendantProcesses
- Specified by:
queryDescendantProcessesin classoshi.software.common.AbstractOperatingSystem
-
getProcess
public oshi.software.os.OSProcess getProcess(int pid) -
getProcessId
public int getProcessId() -
getProcessCount
public int getProcessCount() -
getThreadId
public int getThreadId() -
getCurrentThread
public oshi.software.os.OSThread getCurrentThread() -
getThreadCount
public int getThreadCount() -
getSystemUptime
public long getSystemUptime() -
getSystemBootTime
public long getSystemBootTime() -
getNetworkParams
public oshi.software.os.NetworkParams getNetworkParams() -
getServices
-
getDesktopWindows
- Specified by:
getDesktopWindowsin interfaceoshi.software.os.OperatingSystem- Overrides:
getDesktopWindowsin classoshi.software.common.AbstractOperatingSystem
-
getInstalledApplications
-