Package oshi.util.platform.windows
package oshi.util.platform.windows
Provides utilities for Windows.
-
ClassesClassDescriptionEnables queries of Performance Counters using wild cards to filter instancesUtility to handle Performance Counter QueriesEnables queries of Performance Counters using wild cards to filter instancesHelper class to centralize the boilerplate portions of PDH counter setup and allow applications to easily add, query, and remove counters.Utility to handle WMI Queries.Helper class for WMI