Enum PlatformEnum
- All Implemented Interfaces:
Serializable, Comparable<PlatformEnum>
Deprecated.
An enumeration of supported operating systems. The order of declaration matches the osType constants in the JNA
Platform class.
-
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionDeprecated.UsePlatformEnum.AIXDeprecated.UsePlatformEnum.ANDROIDDeprecated.UsePlatformEnum.DRAGONFLYBSDDeprecated.UsePlatformEnum.FREEBSDDeprecated.UsePlatformEnum.GNUDeprecated.UsePlatformEnum.KFREEBSDDeprecated.UsePlatformEnum.LINUXDeprecated.UsePlatformEnum.MACOSDeprecated.UsePlatformEnum.NETBSDDeprecated.UsePlatformEnum.OPENBSDDeprecated.UsePlatformEnum.SOLARISDeprecated.UsePlatformEnum.UNKNOWNDeprecated.UsePlatformEnum.WINDOWSDeprecated.UsePlatformEnum.WINDOWSCE -
Method Summary
Modifier and TypeMethodDescriptionstatic PlatformEnumDeprecated.UsePlatformEnum.getCurrentPlatform()getName()Deprecated.UsePlatformEnum.getName()static StringgetName(int osType) Deprecated.UsePlatformEnum.getName(int)static PlatformEnumgetValue(int osType) Deprecated.UsePlatformEnum.getValue(int)static PlatformEnumDeprecated.Returns the enum constant of this type with the specified name.static PlatformEnum[]values()Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
MACOS
-
LINUX
Deprecated.UsePlatformEnum.LINUXA flavor of Linux -
WINDOWS
Deprecated.UsePlatformEnum.WINDOWSMicrosoft Windows -
SOLARIS
Deprecated.UsePlatformEnum.SOLARISSolaris (SunOS) -
FREEBSD
-
OPENBSD
-
WINDOWSCE
Deprecated.UsePlatformEnum.WINDOWSCEWindows Embedded Compact -
AIX
-
ANDROID
-
GNU
Deprecated.UsePlatformEnum.GNUGNU operating system -
KFREEBSD
Deprecated.UsePlatformEnum.KFREEBSDDebian GNU/kFreeBSD -
NETBSD
-
DRAGONFLYBSD
Deprecated.UsePlatformEnum.DRAGONFLYBSDDragonFly BSD -
UNKNOWN
Deprecated.UsePlatformEnum.UNKNOWNAn unspecified system
-
-
Method Details
-
values
Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Deprecated.Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getName
Deprecated.UsePlatformEnum.getName()Gets the friendly name of the platform- Returns:
- the friendly name of the platform
-
getName
Deprecated.UsePlatformEnum.getName(int)Gets the friendly name of the platform corresponding to the specified JNA osType ordinal.- Parameters:
osType- The ordinal value matching the order of constants in this enum, corresponding to JNA'sPlatform.getOSType()return values.- Returns:
- the friendly name of the specified platform type
-
getValue
Deprecated.UsePlatformEnum.getValue(int)Gets the value corresponding to the specified JNA osType ordinal.- Parameters:
osType- The ordinal value matching the order of constants in this enum, corresponding to JNA'sPlatform.getOSType()return values.- Returns:
- the value corresponding to the specified platform type
-
getCurrentPlatform
Deprecated.UsePlatformEnum.getCurrentPlatform()Gets the current platform, detected from system properties without loading JNA.- Returns:
- the current platform
-
PlatformEnuminstead.