Class ProcessPerformanceDataJNA
java.lang.Object
oshi.driver.windows.registry.ProcessPerformanceDataJNA
Utility to read process data from HKEY_PERFORMANCE_DATA information with backup from Performance Counters or WMI
-
Method Summary
Modifier and TypeMethodDescriptionQuery PerfMon for process performance countersQuery the registry for process performance counters
-
Method Details
-
buildProcessMapFromRegistry
public static Map<Integer, oshi.driver.common.windows.registry.ProcessPerfCounterBlock> buildProcessMapFromRegistry(Collection<Integer> pids) Query the registry for process performance counters- Parameters:
pids- An optional collection of process IDs to filter the list to. May be null for no filtering.- Returns:
- A map with Process ID as the key and a
ProcessPerfCounterBlockobject populated with performance counter information if successful, or null otherwise.
-
buildProcessMapFromPerfCounters
public static Map<Integer, oshi.driver.common.windows.registry.ProcessPerfCounterBlock> buildProcessMapFromPerfCounters(Collection<Integer> pids) Query PerfMon for process performance counters- Parameters:
pids- An optional collection of process IDs to filter the list to. May be null for no filtering.- Returns:
- A map with Process ID as the key and a
ProcessPerfCounterBlockobject populated with performance counter information.
-