Class WindowsPowerSourceJNA
java.lang.Object
oshi.hardware.common.AbstractPowerSource
oshi.hardware.platform.windows.WindowsPowerSource
oshi.hardware.platform.windows.WindowsPowerSourceJNA
- All Implemented Interfaces:
PowerSource
JNA-based Windows power source implementation.
-
Nested Class Summary
Nested classes/interfaces inherited from interface PowerSource
PowerSource.CapacityUnits -
Field Summary
Fields inherited from class WindowsPowerSource
BATTERY_CAPACITY_RELATIVE, BATTERY_CHARGING, BATTERY_DEVICE_NAME_LEVEL, BATTERY_DISCHARGING, BATTERY_ESTIMATED_TIME_LEVEL, BATTERY_INFORMATION_LEVEL, BATTERY_IS_SHORT_TERM, BATTERY_MANUFACTURE_DATE_LEVEL, BATTERY_MANUFACTURE_NAME_LEVEL, BATTERY_POWER_ON_LINE, BATTERY_SERIAL_NUMBER_LEVEL, BATTERY_SYSTEM_BATTERY, BATTERY_TEMPERATURE_LEVEL, IOCTL_BATTERY_QUERY_INFORMATION, IOCTL_BATTERY_QUERY_STATUS, IOCTL_BATTERY_QUERY_TAG -
Constructor Summary
ConstructorsConstructorDescriptionWindowsPowerSourceJNA(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature) -
Method Summary
Modifier and TypeMethodDescriptionstatic List<PowerSource> Gets Battery Information.protected List<PowerSource> Returns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes().Methods inherited from class AbstractPowerSource
getAmperage, getCapacityUnits, getChemistry, getCurrentCapacity, getCycleCount, getDesignCapacity, getDeviceName, getManufactureDate, getManufacturer, getMaxCapacity, getName, getPowerUsageRate, getRemainingCapacityPercent, getSerialNumber, getTemperature, getTimeRemainingEstimated, getTimeRemainingInstant, getVoltage, isCharging, isDischarging, isPowerOnLine, toString, updateAttributes
-
Constructor Details
-
WindowsPowerSourceJNA
public WindowsPowerSourceJNA(String psName, String psDeviceName, double psRemainingCapacityPercent, double psTimeRemainingEstimated, double psTimeRemainingInstant, double psPowerUsageRate, double psVoltage, double psAmperage, boolean psPowerOnLine, boolean psCharging, boolean psDischarging, PowerSource.CapacityUnits psCapacityUnits, int psCurrentCapacity, int psMaxCapacity, int psDesignCapacity, int psCycleCount, String psChemistry, LocalDate psManufactureDate, String psManufacturer, String psSerialNumber, double psTemperature)
-
-
Method Details
-
queryPowerSources
Description copied from class:AbstractPowerSourceReturns a fresh list of power sources for this platform, used byAbstractPowerSource.updateAttributes(). Each concrete subclass implements this by delegating to its own staticgetPowerSources()factory method.- Specified by:
queryPowerSourcesin classAbstractPowerSource- Returns:
- A list of PowerSource objects representing batteries, etc.
-
getPowerSources
Gets Battery Information.- Returns:
- A list of PowerSource objects representing batteries, etc.
-