Class LinuxOperatingSystem
- All Implemented Interfaces:
OperatingSystem
- Direct Known Subclasses:
LinuxOperatingSystemJNA
-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSorting -
Field Summary
Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMAND -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedConstructor for LinuxOperatingSystem. -
Method Summary
Modifier and TypeMethodDescriptionprotected abstract OSProcesscreateOSProcess(int pid) Creates a newOSProcessinstance for the given PID using the appropriate native implementation.Makes a best effort to get the current thread.static longgetHz()Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.Retrieves a list of installed applications on the system.Instantiates aInternetProtocolStatsobject.static longGets Page Size, for converting memory stats from pages to bytesgetParentPidsFromProcFiles(File[] pidFiles) intGet the number of processes currently runningprotected static StringLooks for a collection of possible distrib-release filenamesGets the all services on the system.Gets currently logged in users.longGet Unix time of boot.longGet the System up time (time since boot).protected intqueryBitness(int jvmBitness) Backup OS-specific query to determine bitness if previous checks failqueryChildProcesses(int parentPid) queryDescendantProcesses(int parentPid) Methods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getFamily, getManufacturer, getProcesses, getVersionInfo, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCurrentProcess, getDesktopWindows, getFileSystem, getNetworkParams, getProcess, getProcesses, getProcesses, getProcessId, getThreadCount, getThreadId, isElevated
-
Constructor Details
-
LinuxOperatingSystem
protected LinuxOperatingSystem()Constructor for LinuxOperatingSystem.
-
-
Method Details
-
queryManufacturer
- Specified by:
queryManufacturerin classAbstractOperatingSystem
-
queryFamilyVersionInfo
- Specified by:
queryFamilyVersionInfoin classAbstractOperatingSystem
-
queryBitness
protected int queryBitness(int jvmBitness) Description copied from class:AbstractOperatingSystemBackup OS-specific query to determine bitness if previous checks fail- Specified by:
queryBitnessin classAbstractOperatingSystem- Parameters:
jvmBitness- The bitness of the JVM- Returns:
- The operating system bitness
-
getInternetProtocolStats
Description copied from interface:OperatingSystemInstantiates aInternetProtocolStatsobject.- Returns:
- a
InternetProtocolStatsobject.
-
getSessions
Description copied from interface:OperatingSystemGets currently logged in users.On macOS, Linux, and Unix systems, the default implementation uses native code (see
man getutxent) that is not thread safe. OSHI's use of this code is synchronized and may be used in a multi-threaded environment without introducing any additional conflicts. Users should note, however, that other operating system code may access the same native code.The
Who#queryWho()method produces similar output parsing the output of the Posix-standardwhocommand, and may internally employ reentrant code on some platforms. Users may opt to use this command-line variant by default using theoshi.os.unix.whoCommandconfiguration property.- Returns:
- A list of
OSSessionobjects representing logged-in users
-
queryAllProcesses
- Specified by:
queryAllProcessesin classAbstractOperatingSystem
-
queryChildProcesses
- Specified by:
queryChildProcessesin classAbstractOperatingSystem
-
queryDescendantProcesses
- Specified by:
queryDescendantProcessesin classAbstractOperatingSystem
-
createOSProcess
-
getParentPidsFromProcFiles
-
getProcessCount
public int getProcessCount()Description copied from interface:OperatingSystemGet the number of processes currently running- Returns:
- The number of processes running
-
getCurrentThread
Description copied from interface:OperatingSystemMakes a best effort to get the current thread. May not be useful in a multithreaded environment. The thread returned may have been short lived and no longer exist.On macOS, returns the oldest thread in the calling process.
- Returns:
- the current thread if known; an invalid thread otherwise.
-
getSystemUptime
public long getSystemUptime()Description copied from interface:OperatingSystemGet the System up time (time since boot).- Returns:
- Number of seconds since boot.
-
getSystemBootTime
public long getSystemBootTime()Description copied from interface:OperatingSystemGet Unix time of boot.- Returns:
- The approximate time at which the system booted, in seconds since the Unix epoch.
-
getInstalledApplications
Description copied from interface:OperatingSystemRetrieves a list of installed applications on the system.This method is implemented per OS. If the OS does not support this feature, it returns an empty list.
- Returns:
- A list of installed applications or an empty list if unsupported.
-
getReleaseFilename
Looks for a collection of possible distrib-release filenames- Returns:
- The first valid matching filename
-
getServices
Description copied from interface:OperatingSystemGets the all services on the system. The definition of what is a service is platform-dependent.- Returns:
- An array of
OSServiceobjects
-
getHz
public static long getHz()Gets Jiffies per second, useful for converting ticks to milliseconds and vice versa.- Returns:
- Jiffies per second.
-
getPageSize
public static long getPageSize()Gets Page Size, for converting memory stats from pages to bytes- Returns:
- Page Size
-