Class LinuxOperatingSystemJNA
java.lang.Object
oshi.software.common.AbstractOperatingSystem
oshi.software.os.linux.LinuxOperatingSystem
oshi.software.os.linux.LinuxOperatingSystemJNA
- All Implemented Interfaces:
OperatingSystem
JNA-based Linux operating system implementation. Extends
LinuxOperatingSystem, providing JNA implementations
of process/thread ID queries and thread count via sysinfo.-
Nested Class Summary
Nested classes/interfaces inherited from interface OperatingSystem
OperatingSystem.OSVersionInfo, OperatingSystem.ProcessFiltering, OperatingSystem.ProcessSorting -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final booleanThis static field identifies if the gettid function is in the c library.static final booleanThis static field identifies if the syscall for gettid returns sane results.static final booleanThis static field identifies if the udev library can be loaded.Fields inherited from class AbstractOperatingSystem
USE_WHO_COMMAND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected OSProcesscreateOSProcess(int pid) Creates a newOSProcessinstance for the given PID using the appropriate native implementation.Instantiates aFileSystemobject.Instantiates aNetworkParamsobject.getProcess(int pid) Gets information on a currently running processintGets the current process ID (PID).intGet the number of threads currently runningintMakes a best effort to get the current thread ID (TID).Methods inherited from class LinuxOperatingSystem
getCurrentThread, getHz, getInstalledApplications, getInternetProtocolStats, getPageSize, getParentPidsFromProcFiles, getProcessCount, getReleaseFilename, getServices, getSessions, getSystemBootTime, getSystemUptime, queryAllProcesses, queryBitness, queryChildProcesses, queryDescendantProcesses, queryFamilyVersionInfo, queryManufacturerMethods inherited from class AbstractOperatingSystem
getBitness, getChildProcesses, getChildrenOrDescendants, getChildrenOrDescendants, getDescendantProcesses, getFamily, getManufacturer, getProcesses, getVersionInfo, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface OperatingSystem
getCurrentProcess, getDesktopWindows, getProcesses, getProcesses, isElevated
-
Field Details
-
HAS_UDEV
public static final boolean HAS_UDEVThis static field identifies if the udev library can be loaded. -
HAS_GETTID
public static final boolean HAS_GETTIDThis static field identifies if the gettid function is in the c library. -
HAS_SYSCALL_GETTID
public static final boolean HAS_SYSCALL_GETTIDThis static field identifies if the syscall for gettid returns sane results.
-
-
Constructor Details
-
LinuxOperatingSystemJNA
public LinuxOperatingSystemJNA()
-
-
Method Details
-
getFileSystem
Description copied from interface:OperatingSystemInstantiates aFileSystemobject.- Returns:
- A
FileSystemobject.
-
getNetworkParams
Description copied from interface:OperatingSystemInstantiates aNetworkParamsobject.- Returns:
- A
NetworkParamsobject.
-
getProcess
Description copied from interface:OperatingSystemGets information on a currently running process- Parameters:
pid- A process ID- Returns:
- An
OSProcessobject for the specified process id if it is running; null otherwise
-
createOSProcess
Description copied from class:LinuxOperatingSystemCreates a newOSProcessinstance for the given PID using the appropriate native implementation.- Specified by:
createOSProcessin classLinuxOperatingSystem- Parameters:
pid- the process ID- Returns:
- a new OS process instance
-
getProcessId
public int getProcessId()Description copied from interface:OperatingSystemGets the current process ID (PID).- Returns:
- the Process ID of the current process
-
getThreadId
public int getThreadId()Description copied from interface:OperatingSystemMakes a best effort to get the current thread ID (TID). May not be useful in a multithreaded environment. The thread ID returned may have been short lived and no longer exist.Thread IDs on macOS are not correlated with any other Operating System output.
- Returns:
- the Thread ID of the current thread if known, 0 otherwise.
-
getThreadCount
public int getThreadCount()Description copied from interface:OperatingSystemGet the number of threads currently running- Returns:
- The number of threads running
-