Class AixFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.os.unix.aix.AixFileSystem
- All Implemented Interfaces:
oshi.software.os.FileSystem
@ThreadSafe
public class AixFileSystem
extends oshi.software.common.AbstractFileSystem
The AIX File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage.-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class oshi.software.common.AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionList<oshi.software.os.OSFileStore> getFileStores(boolean localOnly) longlonglongMethods inherited from class oshi.software.common.AbstractFileSystem
getFileStores
-
Field Details
-
OSHI_AIX_FS_PATH_EXCLUDES
- See Also:
-
OSHI_AIX_FS_PATH_INCLUDES
- See Also:
-
OSHI_AIX_FS_VOLUME_EXCLUDES
- See Also:
-
OSHI_AIX_FS_VOLUME_INCLUDES
- See Also:
-
-
Constructor Details
-
AixFileSystem
public AixFileSystem()
-
-
Method Details
-
getFileStores
-
getOpenFileDescriptors
public long getOpenFileDescriptors() -
getMaxFileDescriptors
public long getMaxFileDescriptors() -
getMaxFileDescriptorsPerProcess
public long getMaxFileDescriptorsPerProcess()
-