Class SolarisFileSystem
java.lang.Object
oshi.software.common.AbstractFileSystem
oshi.software.os.unix.solaris.SolarisFileSystem
- All Implemented Interfaces:
oshi.software.os.FileSystem
@ThreadSafe
public class SolarisFileSystem
extends oshi.software.common.AbstractFileSystem
The Solaris File System contains
OSFileStores which are a storage pool, device, partition,
volume, concrete file system or other implementation specific means of file storage. In Solaris, these are found in
the /proc/mount filesystem, excluding temporary and kernel mounts.-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class oshi.software.common.AbstractFileSystem
NETWORK_FS_TYPES, PSEUDO_FS_TYPES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionList<oshi.software.os.OSFileStore> getFileStores(boolean localOnly) longlonglongMethods inherited from class oshi.software.common.AbstractFileSystem
getFileStores
-
Field Details
-
OSHI_SOLARIS_FS_PATH_EXCLUDES
- See Also:
-
OSHI_SOLARIS_FS_PATH_INCLUDES
- See Also:
-
OSHI_SOLARIS_FS_VOLUME_EXCLUDES
- See Also:
-
OSHI_SOLARIS_FS_VOLUME_INCLUDES
- See Also:
-
-
Constructor Details
-
SolarisFileSystem
public SolarisFileSystem()
-
-
Method Details
-
getFileStores
-
getOpenFileDescriptors
public long getOpenFileDescriptors() -
getMaxFileDescriptors
public long getMaxFileDescriptors() -
getMaxFileDescriptorsPerProcess
public long getMaxFileDescriptorsPerProcess()
-